package de.szut.casino.user;

import de.szut.casino.user.dto.CreateUserDto;
import de.szut.casino.user.dto.GetUserDto;
import de.szut.casino.user.dto.KeycloakUserDto;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpEntity;
import org.springframework.http.HttpHeaders;
import org.springframework.http.HttpMethod;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Service;
import org.springframework.web.client.RestTemplate;

import java.util.Optional;

@Service
public class UserService {
    @Autowired
    private UserRepository userRepository;

    @Autowired
    private RestTemplate http;

    @Autowired
    private UserMappingService mappingService;

    public UserEntity createUser(CreateUserDto createUserDto) {
        UserEntity user = mappingService.mapToUserEntity(createUserDto);
        userRepository.save(user);

        return user;
    }

    public GetUserDto getUser(String authentikId) {
        Optional<UserEntity> user = this.userRepository.findOneByAuthentikId(authentikId);

        return user.map(userEntity -> mappingService.mapToGetUserDto(userEntity)).orElse(null);
    }

    public GetUserDto getCurrentUserAsDto(String token) {
        KeycloakUserDto userData = getAuthentikUserInfo(token);

        if (userData == null) {
            return null;
        }
        Optional<UserEntity> user = this.userRepository.findOneByAuthentikId(userData.getSub());

        return user.map(userEntity -> mappingService.mapToGetUserDto(userEntity)).orElse(null);
    }

    public Optional<UserEntity> getCurrentUser(String token) {
        KeycloakUserDto userData = getAuthentikUserInfo(token);

        if (userData == null) {
            return Optional.empty();
        }
        return this.userRepository.findOneByAuthentikId(userData.getSub());
    }

    private KeycloakUserDto getAuthentikUserInfo(String token) {
        try {
            HttpHeaders headers = new HttpHeaders();
            headers.set("Authorization", token);
            ResponseEntity<KeycloakUserDto> response = this.http.exchange(
                "https://oauth.simonis.lol/application/o/userinfo/", 
                HttpMethod.GET, 
                new HttpEntity<>(headers), 
                KeycloakUserDto.class
            );
            
            return response.getBody();
        } catch (Exception e) {
            System.err.println("Error fetching user info from Authentik: " + e.getMessage());
            return null;
        }
    }

    public boolean exists(String authentikId) {
        return userRepository.existsByAuthentikId(authentikId);
    }
}
